@@ -7,8 +7,8 @@ import (
 
 	"github.com/caarlos0/ctrlc"
 	"github.com/caarlos0/log"
-	"github.com/goreleaser/goreleaser/internal/pipe/defaults"
-	"github.com/goreleaser/goreleaser/pkg/context"
+	"github.com/goreleaser/goreleaser/v2/internal/pipe/defaults"
+	"github.com/goreleaser/goreleaser/v2/pkg/context"
 	"github.com/spf13/cobra"
 )
 
@@ -47,7 +47,7 @@ func newCheckCmd() *checkCmd {
 				ctx.Deprecated = root.deprecated
 
 				if err := ctrlc.Default.Run(ctx, func() error {
-					log.WithField("path", config).
+					log.WithField("path", path).
 						Info(boldStyle.Render("checking"))
 
 					return defaults.Pipe{}.Run(ctx)
