@@ -182,7 +182,7 @@ func (*Builder) Build(ctx *context.Context, build config.Build, options api.Opti
 		a.Type = artifact.CArchive
 		ctx.Artifacts.Add(getHeaderArtifactForLibrary(build, options))
 	}
-	if build.Buildmode == "c-shared" {
+	if build.Buildmode == "c-shared" && !strings.Contains(options.Target, "wasm") {
 		a.Type = artifact.CShared
 		ctx.Artifacts.Add(getHeaderArtifactForLibrary(build, options))
 	}
@@ -365,6 +365,11 @@ func processFlags(ctx *context.Context, a *artifact.Artifact, env, flags []strin
 		if err != nil {
 			return nil, err
 		}
+
+		if flag == "" {
+			continue
+		}
+
 		processed = append(processed, flagPrefix+flag)
 	}
 	return processed, nil
