@@ -8,8 +8,8 @@ import (
 	"text/template"
 
 	"github.com/caarlos0/log"
-	"github.com/goreleaser/goreleaser/internal/logext"
-	"github.com/goreleaser/goreleaser/pkg/context"
+	"github.com/goreleaser/goreleaser/v2/internal/logext"
+	"github.com/goreleaser/goreleaser/v2/pkg/context"
 )
 
 const baseURL = "https://goreleaser.com/deprecations#"
@@ -19,15 +19,17 @@ func Notice(ctx *context.Context, property string) {
 	NoticeCustom(ctx, property, "{{ .Property }} should not be used anymore, check {{ .URL }} for more info")
 }
 
+var urlPropertyReplacer = strings.NewReplacer(
+	".", "",
+	"_", "",
+	":", "",
+	" ", "-",
+)
+
 // NoticeCustom warns the user about the deprecation of the given property.
 func NoticeCustom(ctx *context.Context, property, tmpl string) {
 	// replaces . and _ with -
-	url := baseURL + strings.NewReplacer(
-		".", "",
-		"_", "",
-		":", "",
-		" ", "-",
-	).Replace(property)
+	url := baseURL + urlPropertyReplacer.Replace(property)
 	var out bytes.Buffer
 	if err := template.
 		Must(template.New("deprecation").Parse("DEPRECATED: "+tmpl)).
