@@ -10,15 +10,15 @@ import (
 
 	"github.com/caarlos0/go-shellwords"
 	"github.com/caarlos0/log"
-	"github.com/goreleaser/goreleaser/internal/artifact"
-	"github.com/goreleaser/goreleaser/internal/extrafiles"
-	"github.com/goreleaser/goreleaser/internal/gio"
-	"github.com/goreleaser/goreleaser/internal/logext"
-	"github.com/goreleaser/goreleaser/internal/pipe"
-	"github.com/goreleaser/goreleaser/internal/semerrgroup"
-	"github.com/goreleaser/goreleaser/internal/tmpl"
-	"github.com/goreleaser/goreleaser/pkg/config"
-	"github.com/goreleaser/goreleaser/pkg/context"
+	"github.com/goreleaser/goreleaser/v2/internal/artifact"
+	"github.com/goreleaser/goreleaser/v2/internal/extrafiles"
+	"github.com/goreleaser/goreleaser/v2/internal/gio"
+	"github.com/goreleaser/goreleaser/v2/internal/logext"
+	"github.com/goreleaser/goreleaser/v2/internal/pipe"
+	"github.com/goreleaser/goreleaser/v2/internal/semerrgroup"
+	"github.com/goreleaser/goreleaser/v2/internal/tmpl"
+	"github.com/goreleaser/goreleaser/v2/pkg/config"
+	"github.com/goreleaser/goreleaser/v2/pkg/context"
 )
 
 // Environment variables to pass through to exec
@@ -70,7 +70,6 @@ func executePublisher(ctx *context.Context, publisher config.Publisher) error {
 
 	g := semerrgroup.New(ctx.Parallelism)
 	for _, artifact := range artifacts {
-		artifact := artifact
 		g.Go(func() error {
 			c, err := resolveCommand(ctx, publisher, artifact)
 			if err != nil {
@@ -89,7 +88,7 @@ func executeCommand(c *command, artifact *artifact.Artifact) error {
 		WithField("artifact", artifact.Name).
 		Debug("executing command")
 
-	// nolint: gosec
+	//nolint:gosec
 	cmd := exec.CommandContext(c.Ctx, c.Args[0], c.Args[1:]...)
 	cmd.Env = []string{}
 	for _, key := range passthroughEnvVars {
@@ -164,7 +163,6 @@ func resolveCommand(ctx *context.Context, publisher config.Publisher, artifact *
 	var err error
 	dir := publisher.Dir
 
-	// nolint:staticcheck
 	tpl := tmpl.New(ctx).WithArtifact(artifact)
 	if dir != "" {
 		dir, err = tpl.Apply(dir)
