@@ -3,6 +3,7 @@ package aur
 import (
 	"bufio"
 	"bytes"
+	"crypto/sha256"
 	"errors"
 	"fmt"
 	"os"
@@ -13,14 +14,14 @@ import (
 	"text/template"
 
 	"github.com/caarlos0/log"
-	"github.com/goreleaser/goreleaser/internal/artifact"
-	"github.com/goreleaser/goreleaser/internal/client"
-	"github.com/goreleaser/goreleaser/internal/commitauthor"
-	"github.com/goreleaser/goreleaser/internal/pipe"
-	"github.com/goreleaser/goreleaser/internal/skips"
-	"github.com/goreleaser/goreleaser/internal/tmpl"
-	"github.com/goreleaser/goreleaser/pkg/config"
-	"github.com/goreleaser/goreleaser/pkg/context"
+	"github.com/goreleaser/goreleaser/v2/internal/artifact"
+	"github.com/goreleaser/goreleaser/v2/internal/client"
+	"github.com/goreleaser/goreleaser/v2/internal/commitauthor"
+	"github.com/goreleaser/goreleaser/v2/internal/pipe"
+	"github.com/goreleaser/goreleaser/v2/internal/skips"
+	"github.com/goreleaser/goreleaser/v2/internal/tmpl"
+	"github.com/goreleaser/goreleaser/v2/pkg/config"
+	"github.com/goreleaser/goreleaser/v2/pkg/context"
 )
 
 const (
@@ -110,7 +111,6 @@ func doRun(ctx *context.Context, aur config.AUR, cl client.ReleaseURLTemplater)
 				artifact.ByGoarch("arm"),
 				artifact.Or(
 					artifact.ByGoarm("7"),
-					artifact.ByGoarm("6"),
 				),
 			),
 		),
@@ -386,7 +386,7 @@ func doPublish(ctx *context.Context, pkgs []*artifact.Artifact) error {
 			URL:        cfg.GitURL,
 			SSHCommand: cfg.GitSSHCommand,
 		},
-		Name: cfg.Name,
+		Name: fmt.Sprintf("%x", sha256.Sum256([]byte(cfg.GitURL))),
 	})
 
 	files := make([]client.RepoFile, 0, len(pkgs))
