@@ -1,7 +1,7 @@
 // Package krew implements Piper and Publisher, providing krew plugin manifest
 // creation and upload to a repository (aka krew plugin index).
 //
-// nolint:tagliatelle
+//nolint:tagliatelle
 package krew
 
 import (
@@ -10,20 +10,18 @@ import (
 	"os"
 	"path"
 	"path/filepath"
-	"reflect"
 	"sort"
 	"strings"
 
 	"github.com/caarlos0/log"
-	"github.com/goreleaser/goreleaser/internal/artifact"
-	"github.com/goreleaser/goreleaser/internal/client"
-	"github.com/goreleaser/goreleaser/internal/commitauthor"
-	"github.com/goreleaser/goreleaser/internal/deprecate"
-	"github.com/goreleaser/goreleaser/internal/pipe"
-	"github.com/goreleaser/goreleaser/internal/tmpl"
-	"github.com/goreleaser/goreleaser/internal/yaml"
-	"github.com/goreleaser/goreleaser/pkg/config"
-	"github.com/goreleaser/goreleaser/pkg/context"
+	"github.com/goreleaser/goreleaser/v2/internal/artifact"
+	"github.com/goreleaser/goreleaser/v2/internal/client"
+	"github.com/goreleaser/goreleaser/v2/internal/commitauthor"
+	"github.com/goreleaser/goreleaser/v2/internal/pipe"
+	"github.com/goreleaser/goreleaser/v2/internal/tmpl"
+	"github.com/goreleaser/goreleaser/v2/internal/yaml"
+	"github.com/goreleaser/goreleaser/v2/pkg/config"
+	"github.com/goreleaser/goreleaser/v2/pkg/context"
 )
 
 const (
@@ -56,10 +54,6 @@ func (Pipe) Default(ctx *context.Context) error {
 		if krew.Goamd64 == "" {
 			krew.Goamd64 = "v1"
 		}
-		if !reflect.DeepEqual(krew.Index, config.RepoRef{}) {
-			krew.Repository = krew.Index
-			deprecate.Notice(ctx, "krews.index")
-		}
 	}
 
 	return nil
